﻿using System;
using System.Windows.Forms;
using Steema.TeeChart.Pocket;
using Steema.TeeChart.Styles;
using System.Drawing;
using System.Drawing.Imaging;
using System.Reflection;

namespace ChartTestApp
{
    public partial class Form1 : Form
    {
        private readonly Bitmap m_ChartBitmap;
        private readonly TChart m_Chart;
        private int m_Counter;
        private bool m_AutomaticMode;

        public Form1()
        {
            InitializeComponent();

            m_Counter = 995;
            m_AutomaticMode = true;
            BackColor = Color.White;
            
            m_Chart = new TChart();
            m_Chart.Width = 500;
            m_Chart.Height = 500;

            m_Chart.Axes.Left.Automatic = true;

            m_Chart.Panel.Transparent = true;
            m_Chart.Panel.MarginLeft = 10;
            m_Chart.Panel.MarginUnits = Steema.TeeChart.PanelMarginUnits.Pixels;
            
            m_Chart.Walls.Back.Visible = false;

            m_ChartBitmap = new Bitmap(m_Chart.Width, m_Chart.Height);
            ToggleButtons();
            RecreateSerie();
        }

        protected override void OnPaint(PaintEventArgs e)
        {
            using (Graphics graphics = Graphics.FromImage(m_ChartBitmap))
            {
                ConfigureGraphics(graphics);

                graphics.Clear(Color.Fuchsia);

                m_Chart.Draw(graphics);
            }

            using (ImageAttributes attributes = new ImageAttributes())
            {
                attributes.SetColorKey(Color.Fuchsia, Color.Fuchsia);
                Rectangle bounds = new Rectangle(0, 0, m_Chart.Width, m_Chart.Height);
                e.Graphics.DrawImage(m_ChartBitmap, bounds, 0, 0, m_Chart.Width, m_Chart.Height, GraphicsUnit.Pixel, attributes);
                attributes.ClearColorKey();
            }
            
            base.OnPaint(e);
        }

        public static void ConfigureGraphics(Graphics graphics)
        {
            if (Environment.OSVersion.Platform != PlatformID.WinCE)
            {
                PropertyInfo propertyInfo = graphics.GetType().GetProperty("TextRenderingHint");
                if (propertyInfo != null)
                {
                    propertyInfo.SetValue(graphics, 1, null);
                }
            }
        }

        private void RecreateSerie()
        {
            m_Chart.Series.RemoveAllSeries();
            Bar bar = new Bar();
            bar.Add(new double[] { m_Counter });
            m_Chart.Series.Add(bar);
            Invalidate();
        }

        private void OnAutomaticModeButtonClicked(object sender, EventArgs e)
        {
            if (m_AutomaticMode)
                return;

            m_AutomaticMode = true;
            m_Chart.Axes.Left.Automatic = true;
            m_Counter = 995;
            ToggleButtons();
            RecreateSerie();
        }

        private void OnAddButtonClicked(object sender, EventArgs e)
        {
            m_Counter += 10;
            RecreateSerie();
        }

        private void OnRemoveButtonClicked(object sender, EventArgs e)
        {
            m_Counter -= 10;
            RecreateSerie();
        }

        private void OnManualModeButtonClicked(object sender, EventArgs e)
        {
            m_AutomaticMode = false;
            m_Chart.Axes.Left.Automatic = false;
            m_Chart.Axes.Left.Maximum = 995;
            m_Counter = 980;
            ToggleButtons();
            RecreateSerie();
        }
        private void OnIncreaseButtonClicked(object sender, EventArgs e)
        {
            m_Chart.Axes.Left.Maximum += 10;
            Invalidate();
        }

        private void OnDecreaseButtonClicked(object sender, EventArgs e)
        {
            m_Chart.Axes.Left.Maximum -= 10;
            Invalidate();
        }

        private void ToggleButtons()
        {
            SetAutomaticModeButton.Enabled = !m_AutomaticMode;
            AddButton.Enabled = m_AutomaticMode;
            RemoveButton.Enabled = m_AutomaticMode;

            SetManualModeButton.Enabled = m_AutomaticMode;
            IncreaseButton.Enabled = !m_AutomaticMode;
            DecreaseButton.Enabled = !m_AutomaticMode;
        }
    }
}